BCColorsDark class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accent → const Color
accentForeground → const Color
accentHover → const Color
accentSoft → const Color
accentSoftForeground → const Color
accentSoftHover → const Color
backdrop → const Color
background → const Color
backgroundInverse → const Color
backgroundSecondary → const Color
backgroundTertiary → const Color
border → const Color
borderSecondary → const Color
borderTertiary → const Color
danger → const Color
dangerForeground → const Color
dangerHover → const Color
dangerSoft → const Color
dangerSoftForeground → const Color
dangerSoftHover → const Color
defaultColor → const Color
defaultForeground → const Color
defaultHover → const Color
defaultSoft → const Color
defaultSoftForeground → const Color
defaultSoftHover → const Color
field → const Color
fieldBorder → const Color
fieldBorderFocus → const Color
fieldBorderHover → const Color
fieldFocus → const Color
fieldForeground → const Color
fieldHover → const Color
fieldPlaceholder → const Color
focus → const Color
foreground → const Color
muted → const Color
overlay → const Color
overlayForeground → const Color
segment → const Color
segmentForeground → const Color
separator → const Color
separatorSecondary → const Color
separatorTertiary → const Color
success → const Color
successForeground → const Color
successHover → const Color
successSoft → const Color
successSoftForeground → const Color
successSoftHover → const Color
surface → const Color
surfaceForeground → const Color
surfaceHover → const Color
surfaceSecondary → const Color
surfaceSecondaryForeground → const Color
surfaceTertiary → const Color
surfaceTertiaryForeground → const Color
warning → const Color
warningForeground → const Color
warningHover → const Color
warningSoft → const Color
warningSoftForeground → const Color
warningSoftHover → const Color