BCNavRailDestination class

A destination in a BCNavRail.

Constructors

BCNavRailDestination({required Widget icon, required String label, Widget? selectedIcon, int? badgeCount, bool showDot = false})
const

Properties

badgeCount int?
Shows a small count badge on the icon when non-null and > 0.
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIcon Widget?
Optional distinct icon for the selected state (defaults to icon).
final
showDot bool
Shows a small dot badge (ignored when badgeCount is set).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited